@@ -11,7 +11,7 @@ import logging
 import warnings
 
 from .api import library
-from . import exceptions
+from .exceptions import TYPE_MAP, WandException
 
 
 __all__ = ('genesis', 'terminus', 'increment_refcount', 'decrement_refcount',
@@ -157,6 +157,10 @@ class Resource(object):
 
     @resource.setter
     def resource(self, resource):
+        # Delete the existing resource if there is one
+        if getattr(self, 'c_resource', None):
+            self.destroy()
+
         if self.c_is_resource(resource):
             self.c_resource = resource
         else:
@@ -207,8 +211,8 @@ class Resource(object):
         if severity.value == 0:
             return
         self.c_clear_exception(self.wand)
-        exc_cls = exceptions.TYPE_MAP[severity.value]
-        return exc_cls(ctypes.string_at(desc))
+        exc_cls = TYPE_MAP[severity.value]
+        return exc_cls(desc.value)
 
     def raise_exception(self, stacklevel=1):
         """Raises an exception or warning if it has occurred."""
@@ -231,9 +235,11 @@ class Resource(object):
             pass
 
 
-class DestroyedResourceError(ReferenceError, AttributeError):
+class DestroyedResourceError(WandException, ReferenceError, AttributeError):
     """An error that rises when some code tries access to an already
     destroyed resource.
 
-    """
+    .. versionchanged:: 0.3.0
+       It becomes a subtype of :exc:`wand.exceptions.WandException`.
 
+    """
